@@ -196,7 +196,8 @@ class MongoDbUtil(object):
             clt = self.__mgObj[databaseName].get_collection(collectionName)
             rV = clt.insert_many(dList, ordered=ordered, bypass_document_validation=bypassValidation)
         except Exception as e:
-            logger.error("Bulk insert failing for document length %d with %s", len(dList), str(e))
+            logger.error("Bulk insert failing for document length %d with %s", len(dList), str(e)[:100])
+
             # for ii, dd in enumerate(dList):
             #    logger.error(" %d error doc %r" % (ii, list(dd.keys())))
         #
@@ -459,6 +460,7 @@ class MongoDbUtil(object):
         query constraints.
         """
         dList = []
+        sD = {}
         try:
             qD = queryD if queryD is not None else None
             if selectL:
@@ -491,7 +493,7 @@ class MongoDbUtil(object):
         return 0
 
     def distinct(self, databaseName, collectionName, ky):
-        """ Return a list of distinct values for the input key in the collection. """
+        """Return a list of distinct values for the input key in the collection."""
         rL = []
         try:
             clt = self.__mgObj[databaseName].get_collection(collectionName)
